==> blesta-5.10.2.zip: blesta/core/Automation/Tasks/Task/language/ru_ru/cleanup_logs.php <==
<?php
/**
 * Cleanup Logs
 *
 * @package blesta
 * @subpackage blesta.language.ru_ru
 * @copyright Copyright (c) 2024, Phillips Data, Inc.
 * @license http://www.blesta.com/license/ The Blesta License Agreement
 * @link http://www.blesta.com/ Blesta
 */

$lang['Automation.task.cleanup_logs.logs_cron_deleted'] = '%1$ старых журналов Cron были удалены.';
$lang['Automation.task.cleanup_logs.logs_transaction_deleted'] = '%1$ старых журналов транзакций были удалены.';
$lang['Automation.task.cleanup_logs.logs_service_deleted'] = '%1$ старых журналов обслуживания были удалены.';
$lang['Automation.task.cleanup_logs.logs_client_settings_deleted'] = '%1$s старых журналов настроек клиента были удалены.';
$lang['Automation.task.cleanup_logs.logs_user_deleted'] = '%1$s старых журналов пользователя были удалены.';
$lang['Automation.task.cleanup_logs.logs_messenger_deleted'] = '%1$ старых журналов Messenger были удалены.';
$lang['Automation.task.cleanup_logs.logs_email_deleted'] = '%1$ старых журналов электронной почты были удалены.';
$lang['Automation.task.cleanup_logs.logs_contact_deleted'] = '%1$ старых журналов контактов были удалены.';
$lang['Automation.task.cleanup_logs.logs_accountaccess_deleted'] = '%1$s старых журналов доступа к учетной записи были удалены.';
$lang['Automation.task.cleanup_logs.logs_module_deleted'] = '%1$ старых журналов модуля были удалены.';
$lang['Automation.task.cleanup_logs.logs_gateway_deleted'] = '%1$ старых журналов шлюза были удалены.';
$lang['Automation.task.cleanup_logs.completed'] = 'Задача очистки журналов выполнена.';
$lang['Automation.task.cleanup_logs.attempt'] = 'Попытка очистить старые журналы.';

==> blesta-5.11.4.zip: blesta/core/Automation/Tasks/Task/language/ru_ru/cleanup_logs.php <==
<?php
/**
 * Cleanup Logs
 *
 * @package blesta
 * @subpackage blesta.language.ru_ru
 * @copyright Copyright (c) 2025, Phillips Data, Inc.
 * @license http://www.blesta.com/license/ The Blesta License Agreement
 * @link http://www.blesta.com/ Blesta
 */

$lang['Automation.task.cleanup_logs.logs_cron_deleted'] = '%1$ старых журналов Cron были удалены.';
$lang['Automation.task.cleanup_logs.logs_transaction_deleted'] = '%1$ старых журналов транзакций были удалены.';
$lang['Automation.task.cleanup_logs.logs_service_deleted'] = '%1$ старых журналов обслуживания были удалены.';
$lang['Automation.task.cleanup_logs.logs_client_settings_deleted'] = '%1$s старых журналов настроек клиента были удалены.';
$lang['Automation.task.cleanup_logs.logs_user_deleted'] = '%1$s старых журналов пользователя были удалены.';
$lang['Automation.task.cleanup_logs.logs_messenger_deleted'] = '%1$ старых журналов Messenger были удалены.';
$lang['Automation.task.cleanup_logs.logs_email_deleted'] = '%1$ старых журналов электронной почты были удалены.';
$lang['Automation.task.cleanup_logs.logs_contact_deleted'] = '%1$ старых журналов контактов были удалены.';
$lang['Automation.task.cleanup_logs.logs_accountaccess_deleted'] = '%1$s старых журналов доступа к учетной записи были удалены.';
$lang['Automation.task.cleanup_logs.logs_module_deleted'] = '%1$ старых журналов модуля были удалены.';
$lang['Automation.task.cleanup_logs.logs_gateway_deleted'] = '%1$ старых журналов шлюза были удалены.';
$lang['Automation.task.cleanup_logs.completed'] = 'Задача очистки журналов выполнена.';
$lang['Automation.task.cleanup_logs.attempt'] = 'Попытка очистить старые журналы.';
$lang['Automation.task.cleanup_logs.logs_service_changes_deleted'] = '%1$s старые журналы Service Changes были удалены.';
